@@ -1,5 +1,5 @@
 import numpy as np
-from PyMPDATA.impl.discretisation import from_cdf_1d
+from PyMPDATA_examples.utils.discretisation import from_cdf_1d
 from PyMPDATA_examples.Smolarkiewicz_2006_Figs_3_4_10_11_12.settings import Settings
 from PyMPDATA import Options, Solver, Stepper, ScalarField, VectorField
 from PyMPDATA.boundary_conditions import Periodic
